<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_MX">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Erronea</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Erronea</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dependency error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>DPKG error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>